<template>
  <!-- 搜索 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="编号" prop="itemno">
        <el-input
          v-model="queryParams.itemno"
          placeholder="请输入编号"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="预测项名" prop="itemname">
        <el-input
          v-model="queryParams.itemname"
          placeholder="请输入预测项名"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px" />
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px" />
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['system:tenant:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>
      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list">
      <el-table-column label="编号" align="center" prop="itemno" />
      <el-table-column label="预测项名" align="center" prop="itemname" />
      <el-table-column label="类型ID" align="center" prop="itemtypeid" />
      <el-table-column label="类型名称" align="center" prop="itemtypename" />
      <el-table-column label="粒度" align="center" prop="granularity" />
      <el-table-column label="是否融合" align="center" prop="isfuse" />
      <el-table-column label="是否检查" align="center" prop="workchecked" />
      <el-table-column label="模块ID" align="center" prop="moduleid" />
      <el-table-column label="排序" align="center" prop="itemorder" />
      <el-table-column label="是否启用" align="center" prop="status" />
      <el-table-column label="类别ID" align="center" prop="categoryid" />
      <el-table-column label="数据点ID" align="center" prop="pointid" />
      <el-table-column label="数据点名称" align="center" prop="tagname" />
      <el-table-column label="存放表ID" align="center" prop="resulttableid" />
      <el-table-column label="存放表" align="center" prop="tablename" />

      <el-table-column label="操作" align="center" min-width="110" fixed="right">
        <template #default="scope">
          <el-button
            link
            type="primary"
            @click="openForm('update', scope.row.id)"
            v-hasPermi="['system:tenant:update']"
          >
            编辑
          </el-button>
          <el-button
            link
            type="danger"
            @click="handleDelete(scope.row.id)"
            v-hasPermi="['system:tenant:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <MmPredictItemForm ref="formRef" @success="getList" />

</template>
<script lang="ts" setup>
import MmPredictItemForm from './MmPredictItemForm.vue'
import * as MmPredictItem from '@/api/model/pre/dm'

defineOptions({name: 'DataMmPredictItem'})

  const message = useMessage() // 消息弹窗
  const {t} = useI18n() // 国际化

  const loading = ref(true) // 列表的加载中
  const total = ref(0) // 列表的总页数
  const list = ref([]) // 列表的数据
  const queryParams = reactive({
    pageNo: 1,
    pageSize: 10,
    itemno: undefined,
    itemname: undefined,
  })
  const queryFormRef = ref() // 搜索的表单
  const exportLoading = ref(false) // 导出的加载中

  /** 查询列表 */
  const getList = async () => {
    loading.value = true
    try {
      const page = await MmPredictItem.getMmPredictItemPage(queryParams)
      list.value = page.list
      total.value = page.total
    } finally {
      loading.value = false
    }
  }

  /** 搜索按钮操作 */
  const handleQuery = () => {
    queryParams.pageNo = 1
    getList()
  }

  /** 重置按钮操作 */
  const resetQuery = () => {
    queryFormRef.value.resetFields()
    handleQuery()
  }

  /** 添加/修改操作 */
  const formRef = ref()
  const openForm = (type: string, id?: number) => {
    formRef.value.open(type, id)
  }

  /** 删除按钮操作 */
  const handleDelete = async (id: number) => {
    try {
      // 删除的二次确认
      await message.delConfirm()
      // 发起删除
      await MmPredictItem.deleteMmPredictItem(id)
      message.success(t('common.delSuccess'))
      // 刷新列表
      await getList()
    } catch {
    }
  }

  /** 初始化 **/
  onMounted(async () => {
    await getList()
  })
</script>
